@@ -115,7 +115,7 @@ L<http://www.centralcommand.com/ts/dl/pdf/scanner_en_vexira.pdf>
 
 =head1 AUTHOR
 
-David Skoll (dfs@roaringpenguin.com)
+Dianne Skoll (dfs@roaringpenguin.com)
 
 Dave O'Neill (dmo@roaringpenguin.com)
 
