@@ -116,7 +116,7 @@ L<http://www.sophos.com>
 
 =head1 AUTHOR
 
-David Skoll (dfs@roaringpenguin.com)
+Dianne Skoll (dfs@roaringpenguin.com)
 
 Dave O'Neill (dmo@roaringpenguin.com)
 
