@@ -107,7 +107,7 @@ L<http://www.trendmicro.com/>
 
 =head1 AUTHOR
 
-David Skoll (dfs@roaringpenguin.com)
+Dianne Skoll (dfs@roaringpenguin.com)
 
 Dave O'Neill (dmo@roaringpenguin.com)
 
