@@ -153,7 +153,7 @@ let us know.
 
 =head1 AUTHOR
 
-David Skoll (dfs@roaringpenguin.com)
+Dianne Skoll (dfs@roaringpenguin.com)
 
 Dave O'Neill (dmo@roaringpenguin.com)
 
